# Generated by Django 5.0.3 on 2024-09-20 11:08

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("wetlab", "0023_compoundtreatment_duration_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="compound",
            name="chembl_id",
            field=models.CharField(
                db_index=True, default=None, max_length=32, null=True
            ),
        ),
    ]
