# Generated by Django 5.2 on 2024-11-15 09:38

import bionty.ids
import django.db.models.deletion
import lamindb.base.fields
import lamindb.base.ids
import lamindb.base.users
import lamindb.models
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bionty", "0041_alter_artifactcellline_artifact_and_more"),
        (
            "lamindb",
            "0069_alter_artifact__accessor_alter_artifact__hash_type_and_more",
        ),
        ("wetlab", "0024_compound_chembl_id"),
    ]

    operations = [
        migrations.AlterField(
            model_name="artifactbiosample",
            name="artifact",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="links_biosample",
                to="lamindb.artifact",
            ),
        ),
        migrations.AlterField(
            model_name="artifactbiosample",
            name="biosample",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifact",
                to="wetlab.biosample",
            ),
        ),
        migrations.AlterField(
            model_name="artifactbiosample",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="artifactbiosample",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactbiosample",
            name="feature",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifactbiosample",
                to="lamindb.feature",
            ),
        ),
        migrations.AlterField(
            model_name="artifactbiosample",
            name="feature_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactbiosample",
            name="label_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactbiosample",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcombinationtreatment",
            name="artifact",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="links_combination_treatment",
                to="lamindb.artifact",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcombinationtreatment",
            name="combinationtreatment",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifact",
                to="wetlab.combinationtreatment",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcombinationtreatment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="artifactcombinationtreatment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcombinationtreatment",
            name="feature",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifactcombinationtreatment",
                to="lamindb.feature",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcombinationtreatment",
            name="feature_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactcombinationtreatment",
            name="label_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactcombinationtreatment",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcompound",
            name="artifact",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="links_compound",
                to="lamindb.artifact",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcompound",
            name="compound",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifact",
                to="wetlab.compound",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcompound",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="artifactcompound",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcompound",
            name="feature",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifactcompound",
                to="lamindb.feature",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcompound",
            name="feature_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactcompound",
            name="label_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactcompound",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcompoundtreatment",
            name="artifact",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="links_compound_treatment",
                to="lamindb.artifact",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcompoundtreatment",
            name="compoundtreatment",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifact",
                to="wetlab.compoundtreatment",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcompoundtreatment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="artifactcompoundtreatment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcompoundtreatment",
            name="feature",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifactcompoundtreatment",
                to="lamindb.feature",
            ),
        ),
        migrations.AlterField(
            model_name="artifactcompoundtreatment",
            name="feature_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactcompoundtreatment",
            name="label_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactcompoundtreatment",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="artifactenvironmentaltreatment",
            name="artifact",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="links_environmental_treatment",
                to="lamindb.artifact",
            ),
        ),
        migrations.AlterField(
            model_name="artifactenvironmentaltreatment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="artifactenvironmentaltreatment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactenvironmentaltreatment",
            name="environmentaltreatment",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifact",
                to="wetlab.environmentaltreatment",
            ),
        ),
        migrations.AlterField(
            model_name="artifactenvironmentaltreatment",
            name="feature",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifactenvironmentaltreatment",
                to="lamindb.feature",
            ),
        ),
        migrations.AlterField(
            model_name="artifactenvironmentaltreatment",
            name="feature_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactenvironmentaltreatment",
            name="label_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactenvironmentaltreatment",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="artifactexperiment",
            name="artifact",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="links_experiment",
                to="lamindb.artifact",
            ),
        ),
        migrations.AlterField(
            model_name="artifactexperiment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="artifactexperiment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactexperiment",
            name="experiment",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifact",
                to="wetlab.experiment",
            ),
        ),
        migrations.AlterField(
            model_name="artifactexperiment",
            name="feature",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifactexperiment",
                to="lamindb.feature",
            ),
        ),
        migrations.AlterField(
            model_name="artifactexperiment",
            name="feature_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactexperiment",
            name="label_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactexperiment",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="artifactgenetictreatment",
            name="artifact",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="links_genetic_treatment",
                to="lamindb.artifact",
            ),
        ),
        migrations.AlterField(
            model_name="artifactgenetictreatment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="artifactgenetictreatment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactgenetictreatment",
            name="feature",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifactgenetictreatment",
                to="lamindb.feature",
            ),
        ),
        migrations.AlterField(
            model_name="artifactgenetictreatment",
            name="feature_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactgenetictreatment",
            name="genetictreatment",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifact",
                to="wetlab.genetictreatment",
            ),
        ),
        migrations.AlterField(
            model_name="artifactgenetictreatment",
            name="label_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactgenetictreatment",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttechsample",
            name="artifact",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="links_techsample",
                to="lamindb.artifact",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttechsample",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="artifacttechsample",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttechsample",
            name="feature",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifacttechsample",
                to="lamindb.feature",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttechsample",
            name="feature_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifacttechsample",
            name="label_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifacttechsample",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttechsample",
            name="techsample",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifact",
                to="wetlab.techsample",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttreatmenttarget",
            name="artifact",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="links_treatment_target",
                to="lamindb.artifact",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttreatmenttarget",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="artifacttreatmenttarget",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttreatmenttarget",
            name="feature",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifacttreatmenttarget",
                to="lamindb.feature",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttreatmenttarget",
            name="feature_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifacttreatmenttarget",
            name="label_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifacttreatmenttarget",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="artifacttreatmenttarget",
            name="treatmenttarget",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifact",
                to="wetlab.treatmenttarget",
            ),
        ),
        migrations.AlterField(
            model_name="artifactwell",
            name="artifact",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="links_well",
                to="lamindb.artifact",
            ),
        ),
        migrations.AlterField(
            model_name="artifactwell",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="artifactwell",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="artifactwell",
            name="feature",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifactwell",
                to="lamindb.feature",
            ),
        ),
        migrations.AlterField(
            model_name="artifactwell",
            name="feature_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactwell",
            name="label_ref_is_name",
            field=lamindb.base.fields.BooleanField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="artifactwell",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="artifactwell",
            name="well",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="links_artifact",
                to="wetlab.well",
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="batch",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=60, null=True
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="description",
            field=lamindb.base.fields.TextField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="name",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=255, null=True
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="organism",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="biosamples",
                to="bionty.organism",
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                default=lamindb.base.ids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="biosample",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(auto_now=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="combinationtreatment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="combinationtreatment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="combinationtreatment",
            name="description",
            field=lamindb.base.fields.TextField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="combinationtreatment",
            name="name",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="combinationtreatment",
            name="ontology_id",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=32, null=True
            ),
        ),
        migrations.AlterField(
            model_name="combinationtreatment",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="combinationtreatment",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                default=lamindb.base.ids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="combinationtreatment",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(auto_now=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="compound",
            name="abbr",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=None,
                max_length=32,
                null=True,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="chembl_id",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=32, null=True
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="compound",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="description",
            field=lamindb.base.fields.TextField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="compound",
            name="name",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=256
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="ontology_id",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=32, null=True
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="source",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="bionty.source",
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="synonyms",
            field=lamindb.base.fields.TextField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="compound",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True, default=bionty.ids.ontology, max_length=8, unique=True
            ),
        ),
        migrations.AlterField(
            model_name="compound",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(auto_now=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="compoundtreatment",
            name="concentration",
            field=lamindb.base.fields.FloatField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="compoundtreatment",
            name="concentration_unit",
            field=lamindb.base.fields.CharField(
                blank=True, default=None, max_length=32, null=True
            ),
        ),
        migrations.AlterField(
            model_name="compoundtreatment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="compoundtreatment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="compoundtreatment",
            name="duration",
            field=lamindb.base.fields.DurationField(
                blank=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="compoundtreatment",
            name="name",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="compoundtreatment",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="compoundtreatment",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                default=lamindb.base.ids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="compoundtreatment",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(auto_now=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="environmentaltreatment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="environmentaltreatment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="environmentaltreatment",
            name="duration",
            field=lamindb.base.fields.DurationField(
                blank=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="environmentaltreatment",
            name="name",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="environmentaltreatment",
            name="ontology_id",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=32, null=True
            ),
        ),
        migrations.AlterField(
            model_name="environmentaltreatment",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="environmentaltreatment",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                default=lamindb.base.ids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="environmentaltreatment",
            name="unit",
            field=lamindb.base.fields.CharField(
                blank=True, default=None, max_length=32, null=True
            ),
        ),
        migrations.AlterField(
            model_name="environmentaltreatment",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(auto_now=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="environmentaltreatment",
            name="value",
            field=lamindb.base.fields.FloatField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="date",
            field=lamindb.base.fields.DateField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="description",
            field=lamindb.base.fields.TextField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="name",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                default=lamindb.base.ids.base62_8,
                max_length=8,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="experiment",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(auto_now=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="genetictreatment",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="genetictreatment",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="genetictreatment",
            name="name",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="genetictreatment",
            name="off_target_score",
            field=lamindb.base.fields.FloatField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="genetictreatment",
            name="on_target_score",
            field=lamindb.base.fields.FloatField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="genetictreatment",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="genetictreatment",
            name="sequence",
            field=lamindb.base.fields.TextField(
                blank=True, db_index=True, default=None, null=True
            ),
        ),
        migrations.AlterField(
            model_name="genetictreatment",
            name="system",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=32
            ),
        ),
        migrations.AlterField(
            model_name="genetictreatment",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                default=lamindb.base.ids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="genetictreatment",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(auto_now=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="techsample",
            name="batch",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=60
            ),
        ),
        migrations.AlterField(
            model_name="techsample",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="techsample",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="techsample",
            name="description",
            field=lamindb.base.fields.TextField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="techsample",
            name="name",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="techsample",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="techsample",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                default=lamindb.base.ids.base62_12,
                max_length=12,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="techsample",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(auto_now=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="treatmenttarget",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="treatmenttarget",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="treatmenttarget",
            name="description",
            field=lamindb.base.fields.TextField(blank=True, default=None, null=True),
        ),
        migrations.AlterField(
            model_name="treatmenttarget",
            name="name",
            field=lamindb.base.fields.CharField(
                blank=True, db_index=True, default=None, max_length=60
            ),
        ),
        migrations.AlterField(
            model_name="treatmenttarget",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="treatmenttarget",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                default=lamindb.base.ids.base62_8,
                max_length=8,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="treatmenttarget",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(auto_now=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="well",
            name="column",
            field=lamindb.base.fields.IntegerField(blank=True),
        ),
        migrations.AlterField(
            model_name="well",
            name="created_at",
            field=lamindb.base.fields.DateTimeField(auto_now_add=True, db_index=True),
        ),
        migrations.AlterField(
            model_name="well",
            name="created_by",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.base.users.current_user_id,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.user",
            ),
        ),
        migrations.AlterField(
            model_name="well",
            name="name",
            field=lamindb.base.fields.CharField(
                blank=True,
                db_index=True,
                default=None,
                max_length=32,
                null=True,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="well",
            name="row",
            field=lamindb.base.fields.CharField(blank=True, default=None, max_length=4),
        ),
        migrations.AlterField(
            model_name="well",
            name="run",
            field=lamindb.base.fields.ForeignKey(
                blank=True,
                default=lamindb.models.current_run,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="lamindb.run",
            ),
        ),
        migrations.AlterField(
            model_name="well",
            name="uid",
            field=lamindb.base.fields.CharField(
                blank=True,
                default=lamindb.base.ids.base62_4,
                max_length=4,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="well",
            name="updated_at",
            field=lamindb.base.fields.DateTimeField(auto_now=True, db_index=True),
        ),
    ]
